pub struct Context<Evt> { /* private fields */ }Expand description
Response context for dispatching events back to the main thread.
On native targets, responses are collected in memory for testing.
Clone + 'static — safe to move into spawned tasks.
Implementations
Sourceimpl<Evt> Context<Evt>
impl<Evt> Context<Evt>